---json
{
  "title": "Updating my Obsidian setup",
  "date": "2024-07-16T09:00:00.367Z",
  "tags": [
    "obsidian"
  ],
  "excerpt": "I've been using Obsidian for note taking for about a year now, with limited success, but I've recently made some changes to my configuration that have made it wildly more useful to me"
}
---

I've been using [Obsidian](https://obsidian.md) for note taking for about a year now, with limited success. I knew it was powerful, and could do a lot of thing that I wasn't taking advantage of, but I'd just never really put the time in to make it work for me. So, on a whim, I decided to try out making some changes to my setup and see how well they stick.

## Note structure

I was always using the [periodic notes plugin](https://github.com/liamcain/obsidian-periodic-notes) for automatically creating notes. Originally I was creating a daily note inside a single giant folder, and then switched to weekly notes. Neither really stuck, and the lack of folder structure made finding notes a bit of a pain.

So, I'm now taking advantage of the templating syntax for the plugin. My daily note title format is now `YYYY/MMMM/YYYY-MM-DD`, which generates a folder structure like this:

```
- 2024
  - June
    - 2024-06-30.md
    - 2024-06-29.md
  - July
    - 2024-07-15.md
    - 2024-07-14.md
```

Originally I didn't want the date to be in the filename, but I found that the plugin wouldn't just let me use the day of the month as it wasn't unique, so I had to use the full date.  Regardless, my daily notes now have a decent folder structure that makes them easier to find.

## Task lists

This is the most powerful feature I've started using so far. I've started using the [Tasks plugin](https://github.com/schemar/obsidian-tasks), which lets me define tasks in any note. All of the task parameters can be included in the entry, like due date, priority, scheduled date, etc.

```markdown
* [ ] Task with due date 📅 2024-07-17
* [ ] Task with priority 🔼
* [ ] Task with scheduled date ⏳ 2024-07-17
* [/] Task with custom status
```

It also provides a simple query language to retrieve and filter them. In my daily notes, I list any scheduled tasks for the day, and then also any incomplete tasks are due in the future. I also filter out tasks created in the same note file, to avoid duplication.

```text
> [!check] Due today
> ```tasks
> not done
> (due on or before 2024-07-15) or (scheduled on or before 2024-07-15)
> path does not include {{query.file.path}}
> hide backlink
> hide edit button
> ```
```

And then I create a more urgent section for overdue tasks:

```text
> [!warning] Overdue
> ```tasks
> not done
> has due date
> due before 2024-07-15
> path does not include {{query.file.path}}
>  hide edit button
>  hide backlink
> ```
```

## Automating note creation

Finally, I use the [Templater plugin](https://github.com/SilentVoid13/Templater) to automatically generate the daily note file for the current day.I can use it to fill in the current date for the query, which is then static. I can filter by `due today`, but that query list would then be dynamic and files wouldn't reflect the day they're created for.

{% raw %}
```text
> [!check] Due today
> ```tasks
> not done
> (due on or before {{date:YYYY-MM-DD}}) or (scheduled on or before {{date:YYYY-MM-DD}})
> path does not include {{query.file.path}}
> hide backlink
> hide edit button
> ```
```
{% endraw %}

There are plenty of other things I _could_ be doing, like using [Dataview](https://github.com/blacksmithgu/obsidian-dataview) to pull information from my notes, but what I've got so far is working pretty well and at least lets me track my tasks in one place and keep them organised.

